@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Assert;
 
-our $DATE = '2016-07-26'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 our @Module_Lists = (
     {
@@ -33,8 +33,8 @@ is false. But having to add `if DEBUG` to each assertion is annoying and
 error-prone.
 
 Nowadays, you have several alternatives to have a true, C-like assertions. One
-technique is using `Devel::Declare` (e.g. `PerlX::Assert`). Another technique is
-using `B::CallChecker` (e.g. `Assert::Conditional`).
+technique is using <pm:Devel::Declare> (e.g. <pm:PerlX::Assert>). Another technique is
+using <pm:B::CallChecker> (e.g. <pm:Assert::Conditional>).
 
 _
 
@@ -62,7 +62,7 @@ Acme::CPANLists::PERLANCAR::Assert - Assertion
 
 =head1 VERSION
 
-This document describes version 0.18 of Acme::CPANLists::PERLANCAR::Assert (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-26.
+This document describes version 0.19 of Acme::CPANLists::PERLANCAR::Assert (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-12-28.
 
 =head1 MODULE LISTS
 
@@ -93,8 +93,8 @@ is false. But having to add C<if DEBUG> to each assertion is annoying and
 error-prone.
 
 Nowadays, you have several alternatives to have a true, C-like assertions. One
-technique is using C<Devel::Declare> (e.g. C<PerlX::Assert>). Another technique is
-using C<B::CallChecker> (e.g. C<Assert::Conditional>).
+technique is using L<Devel::Declare> (e.g. L<PerlX::Assert>). Another technique is
+using L<B::CallChecker> (e.g. L<Assert::Conditional>).
 
 
 =over
