@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Avoided;
 
-our $DATE = '2016-07-26'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 our @Module_Lists = (
     {
@@ -11,10 +11,10 @@ our @Module_Lists = (
 This is a list of modules I'm currently avoiding to use in my code, for some
 reason. Most of the modules wered used in my code in the past.
 
-Using a `Dist::Zilla` plugin `Dist::Zilla::Plugin::Acme::CPANLists::Blacklist`,
-you can make sure that during building, your distribution does not specify a
-prerequisite to any of the modules listed here. (You should make your own
-blacklist though).
+Using a <pm:Dist::Zilla> plugin
+<pm:Dist::Zilla::Plugin::Acme::CPANLists::Blacklist>, you can make sure that
+during building, your distribution does not specify a prerequisite to any of the
+modules listed here. (You should make your own blacklist though).
 
 _
         entries => [
@@ -23,8 +23,8 @@ _
                 summary => 'Startup overhead',
                 description => <<'_',
 
-After the 1.x version, I no longer prefer `Log::Any` and am developing an
-alternative called `Log::Gurat`.
+After the 1.x version, I no longer prefer <pm:Log::Any> and am developing an
+alternative called <pm:Log::Gurat>.
 
 _
                 alternate_modules => ['Log::Gurat'],
@@ -34,10 +34,10 @@ _
                 summary => 'Too many deps',
                 description => <<'_',
 
-I used to use `File::Flock` due to its simple interface. However, this module
-depends on things like `AnyEvent`, `Data::Structure::Util`, `File::Slurp`, et
-al, all of which seem unnecessary. Nowadays I'm opting to use
-File::Flock::Retry, or just plain `flock()`.
+I used to use <pm:File::Flock> due to its simple interface. However, this module
+depends on things like <pm:AnyEvent>, <pm:Data::Structure::Util>,
+<pm:File::Slurp>, et al, all of which seem unnecessary. Nowadays I'm opting to
+use <pm:File::Flock::Retry>, or just plain `flock()`.
 
 _
                 alternate_modules => ['File::Flock::Retry'],
@@ -57,7 +57,7 @@ _
                 summary => 'Unnecessary, use Exporter instead',
                 description => <<'_',
 
-I used to use this module because I didn't know that `Exporter` (since perl
+I used to use this module because I didn't know that <pm:Exporter> (since perl
 5.8.3, 2004) can also be used without subclassing, i.e. instead of:
 
     use Exporter;
@@ -70,7 +70,7 @@ you can also use it like this:
     our @EXPORT = (...);
 
 Hence, this module (first released in 2001) is no longer necessary. Besides,
-this module has a worse startup overhead than `Exporter` *and* has less
+this module has a worse startup overhead than <pm:Exporter> *and* has less
 features. So there is absolutely no reason to use it.
 
 _
@@ -82,8 +82,8 @@ _
                 description => <<'_',
 
 JSON.pm is a discouraged module now, due to its somewhat broken backend handling
-and lack of support for `Cpanel::JSON::XS`. consider switching to JSON::MaybeXS
-or perhaps just JSON::PP.
+and lack of support for <pm:Cpanel::JSON::XS>. consider switching to
+<pm:JSON::MaybeXS> or perhaps just <pm:JSON::PP>.
 
 _
                 alternate_modules => ['JSON::MaybeXS', 'JSON::PP', 'Cpanel::JSON::XS'],
@@ -93,9 +93,9 @@ _
                 summary => '',
                 description => <<'_',
 
-`Cpanel::JSON::XS` is the fork of `JSON::XS` that fixes some bugs and adds some
-features, mainly so it's more compatible with `JSON::PP`. See the documentation
-of `Cpanel::JSON::XS` for more details on those.
+<pm:Cpanel::JSON::XS> is the fork of <pm:JSON::XS> that fixes some bugs and adds
+some features, mainly so it's more compatible with <pm:JSON::PP>. See the
+documentation of <pm:Cpanel::JSON::XS> for more details on those.
 
 _
                 alternate_modules => ['Cpanel::JSON::XS'],
@@ -119,7 +119,7 @@ Acme::CPANLists::PERLANCAR::Avoided - Modules I'm currently avoiding
 
 =head1 VERSION
 
-This document describes version 0.18 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-26.
+This document describes version 0.19 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-12-28.
 
 =head1 MODULE LISTS
 
@@ -128,28 +128,28 @@ This document describes version 0.18 of Acme::CPANLists::PERLANCAR::Avoided (fro
 This is a list of modules I'm currently avoiding to use in my code, for some
 reason. Most of the modules wered used in my code in the past.
 
-Using a C<Dist::Zilla> plugin C<Dist::Zilla::Plugin::Acme::CPANLists::Blacklist>,
-you can make sure that during building, your distribution does not specify a
-prerequisite to any of the modules listed here. (You should make your own
-blacklist though).
+Using a L<Dist::Zilla> plugin
+L<Dist::Zilla::Plugin::Acme::CPANLists::Blacklist>, you can make sure that
+during building, your distribution does not specify a prerequisite to any of the
+modules listed here. (You should make your own blacklist though).
 
 
 =over
 
 =item * L<Log::Any> - Startup overhead
 
-After the 1.x version, I no longer prefer C<Log::Any> and am developing an
-alternative called C<Log::Gurat>.
+After the 1.x version, I no longer prefer L<Log::Any> and am developing an
+alternative called L<Log::Gurat>.
 
 
 Alternate modules: L<Log::Gurat>
 
 =item * L<File::Flock> - Too many deps
 
-I used to use C<File::Flock> due to its simple interface. However, this module
-depends on things like C<AnyEvent>, C<Data::Structure::Util>, C<File::Slurp>, et
-al, all of which seem unnecessary. Nowadays I'm opting to use
-File::Flock::Retry, or just plain C<flock()>.
+I used to use L<File::Flock> due to its simple interface. However, this module
+depends on things like L<AnyEvent>, L<Data::Structure::Util>,
+L<File::Slurp>, et al, all of which seem unnecessary. Nowadays I'm opting to
+use L<File::Flock::Retry>, or just plain C<flock()>.
 
 
 Alternate modules: L<File::Flock::Retry>
@@ -164,7 +164,7 @@ Alternate modules: L<File::Slurper>
 
 =item * L<Exporter::Lite> - Unnecessary, use Exporter instead
 
-I used to use this module because I didn't know that C<Exporter> (since perl
+I used to use this module because I didn't know that L<Exporter> (since perl
 5.8.3, 2004) can also be used without subclassing, i.e. instead of:
 
  use Exporter;
@@ -177,7 +177,7 @@ you can also use it like this:
  our @EXPORT = (...);
 
 Hence, this module (first released in 2001) is no longer necessary. Besides,
-this module has a worse startup overhead than C<Exporter> I<and> has less
+this module has a worse startup overhead than L<Exporter> I<and> has less
 features. So there is absolutely no reason to use it.
 
 
@@ -186,17 +186,17 @@ Alternate modules: L<Exporter>
 =item * L<JSON> - Somewhat broken
 
 JSON.pm is a discouraged module now, due to its somewhat broken backend handling
-and lack of support for C<Cpanel::JSON::XS>. consider switching to JSON::MaybeXS
-or perhaps just JSON::PP.
+and lack of support for L<Cpanel::JSON::XS>. consider switching to
+L<JSON::MaybeXS> or perhaps just L<JSON::PP>.
 
 
 Alternate modules: L<JSON::MaybeXS>, L<JSON::PP>, L<Cpanel::JSON::XS>
 
 =item * L<JSON::XS>
 
-C<Cpanel::JSON::XS> is the fork of C<JSON::XS> that fixes some bugs and adds some
-features, mainly so it's more compatible with C<JSON::PP>. See the documentation
-of C<Cpanel::JSON::XS> for more details on those.
+L<Cpanel::JSON::XS> is the fork of L<JSON::XS> that fixes some bugs and adds
+some features, mainly so it's more compatible with L<JSON::PP>. See the
+documentation of L<Cpanel::JSON::XS> for more details on those.
 
 
 Alternate modules: L<Cpanel::JSON::XS>
