@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::LocalCPANMirror;
 
-our $DATE = '2016-07-26'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 our @Module_Lists = (
     {
@@ -20,7 +20,7 @@ _
 
 This module lets you create a so-called "mini mirror", which only contains the
 newest release for each distribution (where CPAN might also contains previous
-versions of a distribution as long as the CPAN author does not cleanup his
+versions of a distribution as long as the CPAN author does not clean up his
 previous releases). This produces a significantly smaller CPAN mirror which you
 can use on your PC/laptop for offline development use.
 
@@ -31,7 +31,7 @@ _
                 description => <<'_',
 
 This application not only lets you download a CPAN mini mirror (using
-`CPAN::Mini` actually) but also indexes the package list and distribution
+<pm:CPAN::Mini> actually) but also index the package list and distribution
 metadata into a SQLite database so you can perform various queries, like list of
 modules/distributions/scripts of a CPAN author, or related modules using
 cross-mention information on modules' PODs, or various rankings.
@@ -57,7 +57,7 @@ Acme::CPANLists::PERLANCAR::LocalCPANMirror - Creating a local CPAN mirror
 
 =head1 VERSION
 
-This document describes version 0.18 of Acme::CPANLists::PERLANCAR::LocalCPANMirror (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-26.
+This document describes version 0.19 of Acme::CPANLists::PERLANCAR::LocalCPANMirror (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-12-28.
 
 =head1 MODULE LISTS
 
@@ -74,7 +74,7 @@ features you can take a look at the modules in this list.
 
 This module lets you create a so-called "mini mirror", which only contains the
 newest release for each distribution (where CPAN might also contains previous
-versions of a distribution as long as the CPAN author does not cleanup his
+versions of a distribution as long as the CPAN author does not clean up his
 previous releases). This produces a significantly smaller CPAN mirror which you
 can use on your PC/laptop for offline development use.
 
@@ -82,7 +82,7 @@ can use on your PC/laptop for offline development use.
 =item * L<App::lcpan>
 
 This application not only lets you download a CPAN mini mirror (using
-C<CPAN::Mini> actually) but also indexes the package list and distribution
+L<CPAN::Mini> actually) but also index the package list and distribution
 metadata into a SQLite database so you can perform various queries, like list of
 modules/distributions/scripts of a CPAN author, or related modules using
 cross-mention information on modules' PODs, or various rankings.
