@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::MagicVariableTechnique;
 
-our $DATE = '2016-07-26'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 our @Module_Lists = (
     {
@@ -44,7 +44,7 @@ _
                 module => 'Umask::Local',
                 description => <<'_',
 
-Like `File::umask`, but instead of using a tied variable, uses an object with
+Like <pm:File::umask>, but instead of using a tied variable, uses an object with
 its `DESTROY` method restoring original umask. I find the interface a bit more
 awkward.
 
@@ -64,7 +64,7 @@ _
                 module => 'Locale::Scope',
                 description => <<'_',
 
-Like `Locale::Tie`, but instead of using a tied variable, uses an object with
+Like <pm:Locale::Tie>, but instead of using a tied variable, uses an object with
 its `DESTROY` method restoring original settings.
 
 _
@@ -88,7 +88,7 @@ Acme::CPANLists::PERLANCAR::MagicVariableTechnique - Modules which employ magic
 
 =head1 VERSION
 
-This document describes version 0.18 of Acme::CPANLists::PERLANCAR::MagicVariableTechnique (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-26.
+This document describes version 0.19 of Acme::CPANLists::PERLANCAR::MagicVariableTechnique (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-12-28.
 
 =head1 MODULE LISTS
 
@@ -123,7 +123,7 @@ Provides C<$UMASK> to get/set umask.
 
 =item * L<Umask::Local>
 
-Like C<File::umask>, but instead of using a tied variable, uses an object with
+Like L<File::umask>, but instead of using a tied variable, uses an object with
 its C<DESTROY> method restoring original umask. I find the interface a bit more
 awkward.
 
@@ -138,7 +138,7 @@ set locale settings.
 
 =item * L<Locale::Scope>
 
-Like C<Locale::Tie>, but instead of using a tied variable, uses an object with
+Like L<Locale::Tie>, but instead of using a tied variable, uses an object with
 its C<DESTROY> method restoring original settings.
 
 
