@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Task::PickingRandomLinesFromFile;
 
-our $DATE = '2016-07-26'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 our @Module_Lists = (
     {
@@ -28,8 +28,8 @@ _
                 description => <<'_',
 
 This module gives you a choice of two algorithms. The first is similar to
-`File::Random` (the scan method), giving each line of the file equal weight. The
-second algorithm is more interesting: it works by random seeking the file,
+<pm:File::Random> (the scan method), giving each line of the file equal weight.
+The second algorithm is more interesting: it works by random seeking the file,
 discarding the line fragment (a.k.a. searching forward for the next newline
 character), reading the next line, then repeating the process until the desired
 number of lines is reached. This means one doesn't have to read the whole file
@@ -48,7 +48,7 @@ _
                 module => 'File::Random::Pick',
                 description => <<'_',
 
-This module is an alternative to `File::Random`. It offers a `random_line()`
+This module is an alternative to <pm:File::Random>. It offers a `random_line()`
 routine that avoids duplication.
 
 _
@@ -57,8 +57,8 @@ _
                 module => 'App::PickRandomLines',
                 description => <<'_',
 
-A CLI that allows you to use `File::Random::Pick` or `File::RandomLine` on the
-command-line.
+A CLI that allows you to use <pm:File::Random::Pick> or <pm:File::RandomLine> on
+the command-line.
 
 _
             },
@@ -81,7 +81,7 @@ Acme::CPANLists::PERLANCAR::Task::PickingRandomLinesFromFile - Picking random li
 
 =head1 VERSION
 
-This document describes version 0.18 of Acme::CPANLists::PERLANCAR::Task::PickingRandomLinesFromFile (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-26.
+This document describes version 0.19 of Acme::CPANLists::PERLANCAR::Task::PickingRandomLinesFromFile (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-12-28.
 
 =head1 MODULE LISTS
 
@@ -103,8 +103,8 @@ If you pick more than one lines, then there might be duplicates.
 =item * L<File::RandomLine> - Recommended for large files
 
 This module gives you a choice of two algorithms. The first is similar to
-C<File::Random> (the scan method), giving each line of the file equal weight. The
-second algorithm is more interesting: it works by random seeking the file,
+L<File::Random> (the scan method), giving each line of the file equal weight.
+The second algorithm is more interesting: it works by random seeking the file,
 discarding the line fragment (a.k.a. searching forward for the next newline
 character), reading the next line, then repeating the process until the desired
 number of lines is reached. This means one doesn't have to read the whole file
@@ -120,14 +120,14 @@ acceptable to you.
 
 =item * L<File::Random::Pick>
 
-This module is an alternative to C<File::Random>. It offers a C<random_line()>
+This module is an alternative to L<File::Random>. It offers a C<random_line()>
 routine that avoids duplication.
 
 
 =item * L<App::PickRandomLines>
 
-A CLI that allows you to use C<File::Random::Pick> or C<File::RandomLine> on the
-command-line.
+A CLI that allows you to use L<File::Random::Pick> or L<File::RandomLine> on
+the command-line.
 
 
 =back
