@@ -1,33 +1,33 @@
 package Acme::CPANLists::PERLANCAR::Task::WorkingWithTree;
 
-our $DATE = '2016-07-26'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.19'; # VERSION
 
 my $text = <<'_';
 **Basics**
 
-Perl classes to represent tree (node) structure: `Tree::Object` and
-`Tree::ObjectXS` (comes with several varieties). They provide methods like
+Perl classes to represent tree (node) structure: <pm:Tree::Object> and
+<pm:Tree::ObjectXS> (comes with several varieties). They provide methods like
 walking a tree, checking whether a node is the first child, getting sibling
 nodes, and so on.
 
-Perl modules to manipulate tree: `Data::Tree`, `Tree::Simple`.
+Perl modules to manipulate tree: <pm:Data::Tree>, <pm:Tree::Simple>.
 
-Memory-efficient tree nodes in Perl: `Tree::Node`.
+Memory-efficient tree nodes in Perl: <pm:Tree::Node>.
 
 
 **Creating**
 
-`Tree::FromStruct`, `Tree::FromText`, `Tree::FromTextLines`,
-`Tree::Create::Callback`, `Tree::Create::Callback::ChildrenPerLevel`,
-`Tree::Create::Size`, `Tree::FromFS`.
+<pm:Tree::FromStruct>, <pm:Tree::FromText>, <pm:Tree::FromTextLines>,
+<pm:Tree::Create::Callback>, <pm:Tree::Create::Callback::ChildrenPerLevel>,
+<pm:Tree::Create::Size>, <pm:Tree::FromFS>.
 
-`Data::Random::Tree`.
+<pm:Data::Random::Tree>.
 
 
 **Visualizing as text**
 
-`Tree::ToText`, `Tree::ToTextLines`.
+<pm:Tree::ToText>, <pm:Tree::ToTextLines>.
 
 
 **Visualizing as graphic**
@@ -37,14 +37,14 @@ TODO
 
 **Other modules**
 
-`Tree::ToFS`.
+<pm:Tree::ToFS>.
 
 Special kinds of trees: TODO.
 
 
 **Roles**
 
-`Role::TinyCommons::Tree`.
+<pm:Role::TinyCommons::Tree>.
 
 _
 
@@ -74,7 +74,7 @@ Acme::CPANLists::PERLANCAR::Task::WorkingWithTree - Working with tree data struc
 
 =head1 VERSION
 
-This document describes version 0.18 of Acme::CPANLists::PERLANCAR::Task::WorkingWithTree (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-07-26.
+This document describes version 0.19 of Acme::CPANLists::PERLANCAR::Task::WorkingWithTree (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-12-28.
 
 =head1 MODULE LISTS
 
@@ -82,26 +82,26 @@ This document describes version 0.18 of Acme::CPANLists::PERLANCAR::Task::Workin
 
 B<Basics>
 
-Perl classes to represent tree (node) structure: C<Tree::Object> and
-C<Tree::ObjectXS> (comes with several varieties). They provide methods like
+Perl classes to represent tree (node) structure: L<Tree::Object> and
+L<Tree::ObjectXS> (comes with several varieties). They provide methods like
 walking a tree, checking whether a node is the first child, getting sibling
 nodes, and so on.
 
-Perl modules to manipulate tree: C<Data::Tree>, C<Tree::Simple>.
+Perl modules to manipulate tree: L<Data::Tree>, L<Tree::Simple>.
 
-Memory-efficient tree nodes in Perl: C<Tree::Node>.
+Memory-efficient tree nodes in Perl: L<Tree::Node>.
 
 B<Creating>
 
-C<Tree::FromStruct>, C<Tree::FromText>, C<Tree::FromTextLines>,
-C<Tree::Create::Callback>, C<Tree::Create::Callback::ChildrenPerLevel>,
-C<Tree::Create::Size>, C<Tree::FromFS>.
+L<Tree::FromStruct>, L<Tree::FromText>, L<Tree::FromTextLines>,
+L<Tree::Create::Callback>, L<Tree::Create::Callback::ChildrenPerLevel>,
+L<Tree::Create::Size>, L<Tree::FromFS>.
 
-C<Data::Random::Tree>.
+L<Data::Random::Tree>.
 
 B<Visualizing as text>
 
-C<Tree::ToText>, C<Tree::ToTextLines>.
+L<Tree::ToText>, L<Tree::ToTextLines>.
 
 B<Visualizing as graphic>
 
@@ -109,51 +109,17 @@ TODO
 
 B<Other modules>
 
-C<Tree::ToFS>.
+L<Tree::ToFS>.
 
 Special kinds of trees: TODO.
 
 B<Roles>
 
-C<Role::TinyCommons::Tree>.
+L<Role::TinyCommons::Tree>.
 
 
 =over
 
-=item * L<Tree::Object>
-
-=item * L<Tree::ObjectXS>
-
-=item * L<Data::Tree>
-
-=item * L<Tree::Simple>
-
-=item * L<Tree::Node>
-
-=item * L<Tree::FromStruct>
-
-=item * L<Tree::FromText>
-
-=item * L<Tree::FromTextLines>
-
-=item * L<Tree::Create::Callback>
-
-=item * L<Tree::Create::Callback::ChildrenPerLevel>
-
-=item * L<Tree::Create::Size>
-
-=item * L<Tree::FromFS>
-
-=item * L<Data::Random::Tree>
-
-=item * L<Tree::ToText>
-
-=item * L<Tree::ToTextLines>
-
-=item * L<Tree::ToFS>
-
-=item * L<Role::TinyCommons::Tree>
-
 =back
 
 =head1 HOMEPAGE
